@@ -292,7 +292,7 @@ zenity_notification (ZenityData *data, ZenityNotificationData *notification_data
   gtk_status_icon_set_visible (status_icon, TRUE);
 
   if(data->timeout_delay > 0) {
-    g_timeout_add (data->timeout_delay * 1000, (GSourceFunc) zenity_util_timeout_handle, NULL);
+    g_timeout_add_seconds (data->timeout_delay, (GSourceFunc) zenity_util_timeout_handle, NULL);
   }
 
   gtk_main ();
